@@ -6,10 +6,13 @@ class Resource(object):
         self.content = content
 
     @classmethod
-    def from_file(cls, path):
-        with open(path) as f:
+    def from_file(cls, path, options=None):
+        with open(path, 'rb') as f:
             content = f.read()
 
+        if options:
+            path = os.path.relpath(path, options['resource_path'])
+
         return Resource(path=path,
                         content=content,
                         )
